@@ -51,16 +51,18 @@
   *	-shutdown  Shutdown afs daemons
   *---------------------------------------------------------------------------*/
 
+#include <afsconfig.h>
+#include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/afsd/afsd.c,v 1.12 2001/07/12 19:58:22 shadow Exp $");
+
 #define VFS 1
 
-#include <afs/param.h>
 #include <afs/cmd.h>
 
 #include <assert.h>
-#include <itc.h>
+#include <potpourri.h>
 #include <afs/afsutil.h>
-#undef in
-#undef out
 #include <stdlib.h>
 #include <stdio.h>
 #include <signal.h>
@@ -72,30 +74,41 @@
 #include <sys/file.h>
 #include <errno.h>
 #include <sys/time.h>
-#ifdef	AFS_DEC_ENV
-#include <sys/param.h>
-#include <sys/fs_types.h>
-#endif
-#if	defined(AFS_SUN_ENV)
-#include <sys/vfs.h>
-#endif
-#ifndef	AFS_AIX41_ENV
-#include <sys/mount.h>
-#endif
 #include <dirent.h>
-#ifdef	  AFS_SUN5_ENV
-#include <sys/fcntl.h>
-#include <sys/mnttab.h>
-#include <sys/mntent.h>
-#else
-#if	defined(AFS_SUN_ENV) || defined(AFS_SGI_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_LINUX20_ENV)
-#include <mntent.h>
-#endif
+
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
 #endif
 
-#if defined(AFS_OSF_ENV) || defined(AFS_DEC_ENV)
+#ifdef HAVE_SYS_FS_TYPES_H
+#include <sys/fs_types.h>
+#endif
+
+#ifdef HAVE_SYS_MOUNT_H
 #include <sys/mount.h>
-#else
+#endif
+
+#ifdef HAVE_SYS_FCNTL_H
+#include <sys/fcntl.h>
+#endif
+
+#ifdef HAVE_SYS_MNTTAB_H
+#include <sys/mnttab.h>
+#endif
+
+#ifdef HAVE_SYS_MNTENT_H
+#include <sys/mntent.h>
+#endif
+
+#ifdef HAVE_MNTENT_H
+#include <mntent.h>
+#endif
+
+#ifdef HAVE_SYS_MOUNT_H
+#include <sys/mount.h>
+#endif
+
+#ifdef HAVE_SYS_VFS_H
 #include <sys/vfs.h>
 #endif
 
@@ -132,7 +145,7 @@ void set_staticaddrs(void);
 #if AFS_HAVE_STATVFS
 #include <sys/statvfs.h>
 #else
-#if !defined(AFS_OSF_ENV)
+#if !defined(AFS_OSF_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
 #include <sys/statfs.h>
 #endif
 #endif
@@ -213,6 +226,9 @@ static int nBiods = 5;			/* AIX3.1 only */
 static int preallocs = 400;		/* Def # of allocated memory blocks */
 static int enable_peer_stats = 0;	/* enable rx stats */
 static int enable_process_stats = 0;	/* enable rx stats */
+#ifdef AFS_AFSDB_ENV
+static int enable_afsdb = 0;		/* enable AFSDB support */
+#endif
 #ifdef notdef
 static int inodes = 60;		        /* VERY conservative, but has to be */
 #endif
@@ -601,6 +617,12 @@ int SweepAFSCache(vFilesFound)
 	}
 	else  if ((strcmp(currp->d_name,          ".") == 0) ||
 	          (strcmp(currp->d_name,         "..") == 0) ||
+#ifdef AFS_DECOSF_ENV
+		  /* these are magic AdvFS files */
+		  (strcmp(currp->d_name,         ".tags") == 0) ||
+		  (strcmp(currp->d_name,         "quota.user") == 0) ||
+		  (strcmp(currp->d_name,         "quota.group") == 0) ||
+#endif
 		  (strcmp(currp->d_name, "lost+found") == 0)) {
 	    /*
 	     * Don't do anything - this file is legit, and is to be left alone.
@@ -703,6 +725,41 @@ struct afsconf_dir *adir; {
     return 0;
 }
 
+#ifdef AFS_AFSDB_ENV
+static AfsdbLookupHandler()
+{
+    afs_int32 kernelMsg[64];
+    char acellName[128];
+    afs_int32 code;
+    struct afsconf_cell acellInfo;
+    int i;
+
+    while (1) {
+	/* On some platforms you only get 4 args to an AFS call */
+	int sizeArg = ((sizeof acellName) << 16) | (sizeof kernelMsg);
+	code = call_syscall(AFSOP_AFSDB_HANDLER, acellName, kernelMsg, sizeArg);
+	if (code) {		/* Something is wrong? */
+	    sleep(1);
+	    continue;
+	}
+
+	code = afsconf_GetAfsdbInfo(acellName, 0, &acellInfo);
+	if (code) {
+	    kernelMsg[0] = 0;
+	    kernelMsg[1] = 0;
+	} else {
+	    kernelMsg[0] = acellInfo.numServers;
+	    if (acellInfo.timeout)
+		kernelMsg[1] = acellInfo.timeout - time(0);
+	    else
+		kernelMsg[1] = 0;
+	    for (i=0; i<acellInfo.numServers; i++)
+		kernelMsg[i+2] = acellInfo.hostAddr[i].sin_addr.s_addr;
+	}    
+    }
+}
+#endif
+
 #ifdef mac2
 #include <sys/ioctl.h>
 #endif /* mac2 */
@@ -890,6 +947,14 @@ mainproc(as, arock)
 	/* -mem_alloc_sleep */
 	cacheFlags |= AFSCALL_INIT_MEMCACHE_SLEEP;
     }
+    if (as->parms[24].items) {
+	/* -afsdb */
+#ifdef AFS_AFSDB_ENV
+	enable_afsdb = 1;
+#else
+	printf("afsd: No AFSDB support; ignoring -afsdb");
+#endif
+    }
 
     /*
      * Pull out all the configuration info for the workstation's AFS cache and
@@ -1109,6 +1174,18 @@ mainproc(as, arock)
     }
 #endif
 
+#ifdef AFS_AFSDB_ENV
+    if (enable_afsdb) {
+	if (afsd_verbose)
+	    printf("%s: Forking AFSDB lookup handler.\n", rn);
+	code = fork();
+	if (code == 0) {
+	    AfsdbLookupHandler();
+	    exit(1);
+	}
+    }
+#endif
+
     /* Initialize AFS daemon threads. */
     if (afsd_verbose)
 	printf("%s: Forking AFS daemon.\n", rn);
@@ -1181,8 +1258,8 @@ mainproc(as, arock)
     }
 
     /*
-         * If the root volume has been explicitly set, tell the kernel.
-         */
+     * If the root volume has been explicitly set, tell the kernel.
+     */
     if (rootVolSet) {
 	if (afsd_verbose)
 	    printf("%s: Calling AFSOP_ROOTVOLUME with '%s'\n",
@@ -1337,6 +1414,9 @@ mainproc(as, arock)
 #ifdef AFS_DEC_ENV
     if ((mount("AFS",cacheMountDir,mountFlags,GT_AFS,(caddr_t) 0)) < 0) {
 #else
+#ifdef AFS_FBSD_ENV
+    if ((mount("AFS",cacheMountDir,mountFlags,(caddr_t) 0)) < 0) {
+#else
 #ifdef	AFS_AUX_ENV
     if ((fsmount(MOUNT_AFS,cacheMountDir,mountFlags,(caddr_t) 0)) < 0)	{
 #else
@@ -1374,7 +1454,6 @@ mainproc(as, arock)
 #else
 #if defined(AFS_SGI_ENV)
     mountFlags = MS_FSS;
-
     if ((mount(MOUNT_AFS,cacheMountDir,mountFlags,(caddr_t) MOUNT_AFS)) < 0) {
 #else
 #ifdef AFS_LINUX20_ENV
@@ -1389,6 +1468,7 @@ mainproc(as, arock)
 #endif /* AFS_HPUX_ENV */
 #endif /* AFS_AIX_ENV */
 #endif /* AFS_AUX_ENV */
+#endif /* AFS_FBSD_ENV */
 #endif /* AFS_DEC_ENV */
          printf("%s: Can't mount AFS on %s(%d)\n",
 		   rn, cacheMountDir, errno);
@@ -1451,6 +1531,11 @@ char **argv; {
     cmd_AddParm(ts, "-enable_peer_stats", CMD_FLAG, CMD_OPTIONAL|CMD_HIDE, "Collect rpc statistics by peer");
     cmd_AddParm(ts, "-enable_process_stats", CMD_FLAG, CMD_OPTIONAL|CMD_HIDE, "Collect rpc statistics for this process");
     cmd_AddParm(ts, "-mem_alloc_sleep", CMD_FLAG, (CMD_OPTIONAL | CMD_HIDE), "Allow sleeps when allocating memory cache");
+    cmd_AddParm(ts, "-afsdb", CMD_FLAG, (CMD_OPTIONAL
+#ifndef AFS_AFSDB_ENV
+		| CMD_HIDE
+#endif
+		), "Enable AFSDB support");
     return (cmd_Dispatch(argc, argv));
 }
 
