@@ -15,13 +15,22 @@
 
 #include <mit-cpyright.h>
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/des/new_rnd_key.c,v 1.8 2001/07/12 19:58:34 shadow Exp $");
+
+#include <des.h>
+#include "des_internal.h"
 #ifdef AFS_PTHREAD_ENV
 #include <pthread.h>
 #endif
+#if defined(HAVE_STRINGS_H)
+#include <strings.h>
+#endif
+#if defined(HAVE_STRING_H)
 #include <string.h>
-#include <des.h>
-#include "des_internal.h"
+#endif
 #include "stats.h"
 
 extern void des_fixup_key_parity();
