@@ -7,26 +7,18 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-/*
- * Revision 2.4  90/10/02  15:47:16
- * Call rxs_Release before losing the security object.
- * 
- * Revision 2.3  90/08/31  16:16:20
- * Move permit_xprt.h.
- * 
- * Revision 2.2  90/08/20  11:14:37
- * Include permit_xprt.h.
- * Cleanup; prune log data, line length <= 79.
- * Rename cbc_encrypt -> des_cbc_encrypt (etc).
- * 
- * Revision 2.1  90/08/07  19:10:21
- * Start with clean version to sync test and dev trees.
- * */
-
 /* These routines provide a convenient interface to the AuthServer. */
 
+#include <afsconfig.h>
 #if defined(UKERNEL)
 #include "../afs/param.h"
+#else
+#include <afs/param.h>
+#endif
+
+RCSID("$Header: /cvs/openafs/src/kauth/authclient.c,v 1.6 2001/07/12 19:58:40 shadow Exp $");
+
+#if defined(UKERNEL)
 #include "../afs/sysincludes.h"
 #include "../afs/afsincludes.h"
 #include "../afs/afs_usrops.h"
@@ -43,9 +35,7 @@
 #include "../afs/kautils.h"
 #include "../afs/pthread_glock.h"
 
-#include "../afs/permit_xprt.h"
 #else /* defined(UKERNEL) */
-#include <afs/param.h>
 #include <afs/stds.h>
 #include <afs/pthread_glock.h>
 #include <sys/types.h>
@@ -63,8 +53,6 @@
 #include <afs/afsutil.h>
 #include "kauth.h"
 #include "kautils.h"
-
-#include "../permit_xprt.h"
 #endif /* defined(UKERNEL) */
 
 
@@ -791,8 +779,13 @@ afs_int32 ka_ChangePassword (
     afs_int32	   code;
 
     LOCK_GLOBAL_MUTEX
+#ifdef AFS_S390_LINUX20_ENV
+    code = ubik_Call_New (KAM_SetPassword, conn, 0, name, 
+                         instance, 0, 0, *newkey);
+#else
     code = ubik_Call_New (KAM_SetPassword, conn, 0, name, 
 			  instance, 0, *newkey);
+#endif
     UNLOCK_GLOBAL_MUTEX
     return code;
 }
