@@ -7,19 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-/*
- * Revision 2.3  1991/12/30  20:36:46
- * #837: Added AuthLog support for the kaserver
- *
- * Revision 2.2  90/08/29  15:10:50
- * Cleanups.
- * Don't create rxvab security object.
- * 
- * Revision 2.1  90/08/07  19:11:30
- * Start with clean version to sync test and dev trees.
- * */
-
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.8 2001/07/12 19:58:40 shadow Exp $");
+
 #include <afs/stds.h>
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -163,7 +155,6 @@ main (argc, argv)
     struct rx_securityClass *sca[1];
     struct rx_securityClass *scm[3];
     
-    extern int afsconf_ClientAuth();
     extern int afsconf_ClientAuthSecure();
     extern int afsconf_ServerAuth();
     extern int afsconf_CheckAuth();
